@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2015-03-26'; # DATE
-our $VERSION = '1.01'; # VERSION
+our $DATE = '2015-03-30'; # DATE
+our $VERSION = '1.02'; # VERSION
 
 use 5.010001;
 use strict;
@@ -488,7 +488,7 @@ sub do_completion {
 
     require Perinci::Sub::Complete;
     my $compres = Perinci::Sub::Complete::complete_cli_arg(
-        meta            => $meta,
+        meta            => $meta, # must be normalized
         words           => $words,
         cword           => $cword,
         common_opts     => $self->common_opts,
@@ -738,6 +738,7 @@ sub _parse_argv2 {
             argv                => \@ARGV,
             args                => \%args,
             meta                => $meta,
+            meta_is_normalized  => 1,
             allow_extra_elems   => $has_cmdline_src ? 1:0,
             per_arg_json        => $self->{per_arg_json},
             per_arg_yaml        => $self->{per_arg_yaml},
@@ -758,6 +759,15 @@ sub _parse_argv2 {
             },
         );
 
+        return $res unless $res->[0] == 200;
+
+        require Perinci::Sub::CoerceArgs;
+        $res = Perinci::Sub::CoerceArgs::coerce_args(
+            meta                => $meta,
+            meta_is_normalized  => 1,
+            args                => $res->[2],
+        );
+
         # restore
         for (keys %$copts) {
             $copts->{$_}{handler} = $old_handlers{$_};
@@ -1195,7 +1205,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.01 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-03-26.
+This document describes version 1.02 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-03-30.
 
 =head1 DESCRIPTION
 
@@ -1997,7 +2007,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Cm
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-CmdLine-Lite>.
 
 =head1 BUGS
 
